<!-- #region -->
# Welcome to GBasis's Documentation!

[Gbasis](https://github.com/theochem/gbasis/) is a free, open-source, and cross-platform Python library designed to help you effortlessly work with Gaussian-type orbitals. Please use the following citation in any publication using Gbasis library:

**"GBasis: A Python Library for Evaluating Functions, Functionals, and
Integrals Expressed with Gaussian Basis Functions"**,
Taewon David Kim, Leila Pujal, Maximilian van Zyl, Alireza Tehrani, Michelle Richer, Gabriela
Sánchez-Díaz, Xiaotian Derrick Yang, Valerii Chuiko, Raymundo Hernández-Esparza, William Adams,
Xiaomin Huang, Braden D. Kelly, Matthew Chan, Esteban Vöhringer-Martinez, Toon Verstraelen, Farnaz
Heidar-Zadeh, and Paul W. Ayers

The GBasis source code is hosted on [GitHub](https://github.com/theochem/gbasis/) and is released under the [GNU LESSER GENERAL PUBLIC LICENSE](https://github.com/theochem/gbasis/blob/master/LICENSE). We welcome any contributions to the GBasis library in accordance with our [Code of Conduct](https://github.com/theochem/gbasis/blob/master/CODE_OF_CONDUCT.md); please see our [Contributing Guidelines](https://github.com/theochem/gbasis/blob/master/CONTRIBUTING.md). Please report any issues you encounter while using GBasis library on [GitHub Issues](https://github.com/theochem/gbasis/issues). For further information and inquiries please contact us at qcdevs@gmail.com.

## Why GBasis?
GBasis is a pure-Python package for evaluating and analytically integrating Gaussian-type orbitals and their related quantities. The goal is to build a set of tools to the quantum chemistry community that are easily accessible and easy to use as to facilitate future scientific works.

Since basis set manipulation is often slow, Quantum Chemistry packages in Python often interface to a lower-level lanaguage, such as C++ and Fortran, for these parts, resulting in a more difficult build process and limited distribution. The hope is that gbasis can fill in this gap without a significant difference in performance.

<!-- #endregion -->
